"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@salaxy/core");
/**
 * Provides wrapper methods for communicating with the Palkkaus.fi API.
 * The raw Ajax-access to the server methods: GET, POST and DELETE
 * with different return types and authentication / error events.
 * This is the JQuery based ajax implementation.
 */
var AjaxJQuery = /** @class */ (function () {
    /**
     * Creates a new instance of AjaxJQuery
     */
    function AjaxJQuery() {
        /**
         * By default (true) the token is set to salaxy-token -cookie.
         * Disable cookies with this flag.
         */
        this.useCookie = true;
        /**
         * By default credentials are not used in http-calls.
         * Enable credentials with this flag.
         */
        this.useCredentials = false;
        /**
         * The server address - root of the server. This is settable field.
         * Will probably be changed to a configuration object in the final version.
         */
        this.serverAddress = "https://test-api.salaxy.com";
        // apiServer
        if (salaxy && salaxy.config && salaxy.config.apiServer) {
            this.serverAddress = salaxy.config.apiServer;
        }
        // useCredentials
        if (salaxy && salaxy.config && salaxy.config.useCredentials != null) {
            this.useCredentials = salaxy.config.useCredentials;
        }
        // useCookie
        if (salaxy && salaxy.config && salaxy.config.useCookie != null) {
            this.useCookie = salaxy.config.useCookie;
        }
    }
    /** Gets the API address with version information. E.g. 'https://test-api.salaxy.com/v02/api' */
    AjaxJQuery.prototype.getApiAddress = function () {
        return this.serverAddress + "/v02/api";
    };
    /** Gets the Server address that is used as bases to the HTML queries. E.g. 'https://test-api.salaxy.com' */
    AjaxJQuery.prototype.getServerAddress = function () {
        return this.serverAddress;
    };
    /**
     * Gets a JSON-message from server using the API
     *
     * @param method - The API method is the url path after the api version segments (e.g. '/v02/api')
     *        and starts with a forward slash, e.g. '/calculator/new', or a full URL address.
     *
     * @return A Promise with result data. Standard Promise rejection to be used for error handling.
     */
    AjaxJQuery.prototype.getJSON = function (method) {
        var token = this.getCurrentToken();
        return this.getJQuery().ajax({
            dataType: "json",
            url: this.getUrl(method),
            xhrFields: {
                withCredentials: (token) ? false : this.useCredentials,
            },
            beforeSend: function (request) {
                if (token) {
                    request.setRequestHeader("Authorization", "Bearer " + token);
                }
            },
        });
    };
    /**
     * Gets a HTML-message from server using the API
     *
     * @param method - The API method is the url path after the api version segments (e.g. '/v02/api')
     *        and starts with a forward slash, e.g. '/calculator/new', or a full URL address.
     *
     * @return A Promise with result html. Standard Promise rejection to be used for error handling.
     */
    AjaxJQuery.prototype.getHTML = function (method) {
        var token = this.getCurrentToken();
        return this.getJQuery().ajax({
            dataType: "html",
            url: this.getUrl(method),
            xhrFields: {
                withCredentials: (token) ? false : this.useCredentials,
            },
            beforeSend: function (request) {
                if (token) {
                    request.setRequestHeader("Authorization", "Bearer " + token);
                }
            },
        });
    };
    /**
     * POSTS data to server and receives back a JSON-message.
     *
     * @param method - The API method is the url path after the api version segments (e.g. '/v02/api')
     *        and starts with a forward slash, e.g. '/calculator/new', or a full URL address.
     * @param data - The data that is posted to the server.
     *
     * @return A Promise with result data. Standard Promise rejection to be used for error handling.
     */
    AjaxJQuery.prototype.postJSON = function (method, data) {
        var token = this.getCurrentToken();
        return this.getJQuery().ajax({
            type: "POST",
            url: this.getUrl(method),
            data: data,
            dataType: "json",
            xhrFields: {
                withCredentials: (token) ? false : this.useCredentials,
            },
            beforeSend: function (request) {
                if (token) {
                    request.setRequestHeader("Authorization", "Bearer " + token);
                }
            },
        });
    };
    /**
     * POSTS data to server and receives back HTML.
     *
     * @param method - The API method is the url starting from api version, e.g. '/v02/api'. E.g. '/calculator/new'
     * @param data - The data that is posted to the server.
     *
     * @return A Promise with result data. Standard Promise rejection to be used for error handling.
     */
    AjaxJQuery.prototype.postHTML = function (method, data) {
        var token = this.getCurrentToken();
        return this.getJQuery().ajax({
            type: "POST",
            url: this.getUrl(method),
            data: data,
            dataType: "html",
            xhrFields: {
                withCredentials: (token) ? false : this.useCredentials,
            },
            beforeSend: function (request) {
                if (token) {
                    request.setRequestHeader("Authorization", "Bearer " + token);
                }
            },
        });
    };
    /**
     * Sends a DELETE-message to server using the API
     *
     * @param method - The API method is the url path after the api version segments (e.g. '/v02/api')
     *        and starts with a forward slash, e.g. '/calculator/new', or a full URL address.
     *
     * @return A Promise with result data. Standard Promise rejection to be used for error handling.
     */
    AjaxJQuery.prototype.remove = function (method) {
        var token = this.getCurrentToken();
        return this.getJQuery().ajax({
            type: "DELETE",
            url: this.getUrl(method),
            xhrFields: {
                withCredentials: (token) ? false : this.useCredentials,
            },
            beforeSend: function (request) {
                if (token) {
                    request.setRequestHeader("Authorization", "Bearer " + token);
                }
            },
        });
    };
    /**
     * Gets the current token.
     * Will check the salaxy-token cookie if the token is persisted there
     */
    AjaxJQuery.prototype.getCurrentToken = function () {
        if (!this.token && this.useCookie) {
            this.token = new core_1.Cookies().get("salaxy-token") || "";
        }
        return this.token;
    };
    /**
     * Sets the current token. The token is set to cookie called "salaxy-token" or
     * if the HTML page is running from local computer, it is set to local storage.
     *
     * @param token - the authentication token to store.
     */
    AjaxJQuery.prototype.setCurrentToken = function (token) {
        if (this.useCookie) {
            new core_1.Cookies().setCookie("salaxy-token", token || "");
        }
        this.token = token;
    };
    /**
     * Implements the OAuth2 "Resource Owner Password Credentials Grant" flow (RFC6749 4.3).
     * This method is not typically used in production web sites - use Implicit Grant instead for client side JavScript (SPAs).
     * However, it is very useful in development, testing, trusted helpers and server-side scenarios.
     */
    AjaxJQuery.prototype.resourceOwnerLogin = function (username, password) {
        var _this = this;
        return this.getJQuery().ajax({
            type: "POST",
            url: this.getServerAddress() + "/oauth2/token",
            data: {
                grant_type: "password",
                username: username,
                password: password,
            },
            success: function (data, textStatus, request) {
                _this.setCurrentToken(data.access_token);
            },
            dataType: "json",
        });
    };
    AjaxJQuery.prototype.getJQuery = function () {
        var jQuery = window.jQuery;
        if (jQuery) {
            return jQuery;
        }
        else {
            throw new Error("ERROR: No jQuery. AjaxJQuery requires jQuery to be referenced.");
        }
    };
    /** If missing, append the API server address to the given url method string */
    AjaxJQuery.prototype.getUrl = function (method) {
        if (!method || method.trim() === "") {
            return null;
        }
        if (method.toLowerCase().startsWith("http")) {
            return method;
        }
        if (method.toLowerCase().startsWith("/v")) {
            return this.getServerAddress() + method;
        }
        return this.getApiAddress() + method;
    };
    return AjaxJQuery;
}());
exports.AjaxJQuery = AjaxJQuery;
//# sourceMappingURL=AjaxJQuery.js.map